@@ -58,6 +58,9 @@
   (mapv (fn [^Integer i] (keyword (.getColumnLabel rsmeta i)))
         (range 1 (inc (if rsmeta (.getColumnCount rsmeta) 0)))))
 
+(defn- validate [expr ^String msg]
+  (when-not expr (throw (IllegalArgumentException. msg))))
+
 (defn get-modified-column-names
   "Given `ResultSetMetaData`, return a vector of modified column names, each
   qualified by the table from which it came.
@@ -66,8 +69,8 @@
   [^ResultSetMetaData rsmeta opts]
   (let [qf (:qualifier-fn opts)
         lf (:label-fn opts)]
-    (assert qf ":qualifier-fn is required")
-    (assert lf ":label-fn is required")
+    (validate qf ":qualifier-fn is required")
+    (validate lf ":label-fn is required")
     (mapv (fn [^Integer i]
             (if-let [q (some-> (get-table-name rsmeta i) (qf) (not-empty))]
               (keyword q (-> (.getColumnLabel rsmeta i) (lf)))
@@ -81,7 +84,7 @@
   Requires the `:label-fn` option."
   [^ResultSetMetaData rsmeta opts]
   (let [lf (:label-fn opts)]
-    (assert lf ":label-fn is required")
+    (validate lf ":label-fn is required")
     (mapv (fn [^Integer i] (keyword (lf (.getColumnLabel rsmeta i))))
           (range 1 (inc (if rsmeta (.getColumnCount rsmeta) 0))))))
 
@@ -275,6 +278,10 @@
                               :qualifier-fn ->kebab-case
                               :label-fn ->kebab-case)))
 
+(comment
+  (->kebab-case "_id") ;;=> "id"!!
+  )
+
 (defn as-unqualified-kebab-maps
   "Given a `ResultSet` and options, return a `RowBuilder` / `ResultSetBuilder`
   that produces bare vectors of hash map rows, with simple, kebab-case keys."
@@ -906,7 +913,7 @@
                                          (first sql-params)
                                          (rest sql-params)
                                          opts)]
-            (reduce-stmt stmt f init opts)))
+          (reduce-stmt stmt f init opts)))
       r/CollFold
       (coll-fold [_ n combinef reducef]
         (with-open [con  (p/get-connection this opts)
@@ -922,12 +929,12 @@
                                      (first sql-params)
                                      (rest sql-params)
                                      opts)]
-        (if-let [rs (stmt->result-set stmt opts)]
-          (let [builder-fn (get opts :builder-fn as-maps)
-                builder    (builder-fn rs opts)]
-            (when (.next rs)
-                  (datafiable-row (row-builder builder) this opts)))
-          {:next.jdbc/update-count (.getUpdateCount stmt)})))
+      (if-let [rs (stmt->result-set stmt opts)]
+        (let [builder-fn (get opts :builder-fn as-maps)
+              builder    (builder-fn rs opts)]
+          (when (.next rs)
+            (datafiable-row (row-builder builder) this opts)))
+        {:next.jdbc/update-count (.getUpdateCount stmt)})))
   (-execute-all [this sql-params opts]
     (with-open [con  (p/get-connection this opts)
                 stmt (prepare/create con
@@ -951,14 +958,14 @@
     (reify
       clojure.lang.IReduceInit
       (reduce [_ f init]
-        (reduce-stmt this f init (assoc opts :return-keys true)))
+        (reduce-stmt this f init (merge {:return-keys true} opts)))
       r/CollFold
       (coll-fold [_ n combinef reducef]
         (fold-stmt this n combinef reducef (.getConnection this)
-                   (assoc opts :return-keys true)))
+                   (merge {:return-keys true} opts)))
       (toString [_] "`IReduceInit` from `plan` -- missing reduction?")))
   (-execute-one [this _ opts]
-    (if-let [rs (stmt->result-set this (assoc opts :return-keys true))]
+    (if-let [rs (stmt->result-set this (merge {:return-keys true} opts))]
       (let [builder-fn (get opts :builder-fn as-maps)
             builder    (builder-fn rs opts)]
         (when (.next rs)
@@ -969,17 +976,17 @@
     (if (:multi-rs opts)
       (loop [go (.execute this) acc []]
         (if-let [rs (stmt->result-set-update-count
-                     (.getConnection this) this go (assoc opts :return-keys true))]
+                     (.getConnection this) this go (merge {:return-keys true} opts))]
           (recur (.getMoreResults this) (conj acc rs))
           acc))
-      (if-let [rs (stmt->result-set this (assoc opts :return-keys true))]
+      (if-let [rs (stmt->result-set this (merge {:return-keys true} opts))]
         (datafiable-result-set rs (.getConnection this) opts)
         [{:next.jdbc/update-count (.getUpdateCount this)}])))
 
   java.sql.Statement
   (-execute [this sql-params opts]
-    (assert (= 1 (count sql-params))
-            "Parameters cannot be provided when executing a non-prepared Statement")
+    (validate (= 1 (count sql-params))
+              "Parameters cannot be provided when executing a non-prepared Statement")
     (reify
       clojure.lang.IReduceInit
       (reduce [_ f init]
@@ -990,8 +997,8 @@
                        (.getConnection this) opts))
       (toString [_] "`IReduceInit` from `plan` -- missing reduction?")))
   (-execute-one [this sql-params opts]
-    (assert (= 1 (count sql-params))
-            "Parameters cannot be provided when executing a non-prepared Statement")
+    (validate (= 1 (count sql-params))
+              "Parameters cannot be provided when executing a non-prepared Statement")
     (if-let [rs (stmt-sql->result-set this (first sql-params))]
       (let [builder-fn (get opts :builder-fn as-maps)
             builder    (builder-fn rs opts)]
@@ -1000,12 +1007,12 @@
                           (.getConnection this) opts)))
       {:next.jdbc/update-count (.getUpdateCount this)}))
   (-execute-all [this sql-params opts]
-    (assert (= 1 (count sql-params))
-            "Parameters cannot be provided when executing a non-prepared Statement")
+    (validate (= 1 (count sql-params))
+              "Parameters cannot be provided when executing a non-prepared Statement")
     (if (:multi-rs opts)
       (loop [go (.execute this (first sql-params)) acc []]
         (if-let [rs (stmt->result-set-update-count
-                     (.getConnection this) this go (assoc opts :return-keys true))]
+                     (.getConnection this) this go (merge {:return-keys true} opts))]
           (recur (.getMoreResults this) (conj acc rs))
           acc))
       (if-let [rs (stmt-sql->result-set this (first sql-params))]
@@ -1037,7 +1044,7 @@
   (let [fk-suffix (get-in opts [:schema-opts :fk-suffix] "id")
         pk        (get-in opts [:schema-opts :pk]        "id")
         pk-fn     (get-in opts [:schema-opts :pk-fn]     (constantly (name pk)))
-        [_ table] (re-find (re-pattern (str "(?i)^(.+?)_?"
+        [_ table] (re-find (re-pattern (str "(?i)^(.+?)[-_]?"
                                             (name fk-suffix)
                                             "$"))
                            (name col))]
@@ -1050,8 +1057,10 @@
   (default-schema {} :user_statusid)
   (default-schema {:schema-opts {:fk-suffix "did"}} :user_id)
   (default-schema {:schema-opts {:fk-suffix "did"}} :user_did)
+  (default-schema {:schema-opts {:fk-suffix "did"}} :user-did)
   (default-schema {:schema-opts {:fk-suffix "(did|id)"}} :user_id)
   (default-schema {:schema-opts {:fk-suffix "(did|id)"}} :user_did)
+  (default-schema {:schema-opts {:fk-suffix "(did|id)"}} :user-did)
   (default-schema {:schema-opts {:fk-suffix "(did|id)"
                                  :pk :did}} :user_did)
   (default-schema {:schema-opts {:fk-suffix "(did|id)"
@@ -1061,6 +1070,13 @@
                                             "id"
                                             pk))}}
                   :user_did)
+  (default-schema {:schema-opts {:fk-suffix "(did|id)"
+                                 :pk :did
+                                 :pk-fn (fn [table pk]
+                                          (if (= "user" table)
+                                            "id"
+                                            pk))}}
+                  :user-did)
   (default-schema {:schema-opts {:fk-suffix "(did|id)"
                                  :pk :did
                                  :pk-fn (fn [table pk]
